@@ -2,6 +2,7 @@
 # SPDX-License-Identifier: GPL-3.0-or-later
 import multiprocessing
 import os
+import pmb.parse.arch
 import sys
 
 #
@@ -15,9 +16,10 @@ from pmb.config.merge_with_args import merge_with_args
 #
 # Exported variables (internal configuration)
 #
-version = "1.38.0"
+version = "1.39.0"
 pmb_src = os.path.normpath(os.path.realpath(__file__) + "/../../..")
 apk_keys_path = pmb_src + "/pmb/data/keys"
+arch_native = pmb.parse.arch.alpine_native()
 
 # apk-tools minimum version
 # https://pkgs.alpinelinux.org/packages?name=apk-tools&branch=edge
@@ -60,6 +62,7 @@ config_keys = ["aports",
                "kernel",
                "keymap",
                "locale",
+               "mirror_alpine",
                "mirrors_postmarketos",
                "nonfree_firmware",
                "nonfree_userland",
@@ -255,6 +258,21 @@ build_device_architectures = ["armhf", "armv7", "aarch64", "x86_64", "x86"]
 # for the first time
 build_packages = ["abuild", "build-base", "ccache", "git"]
 
+#
+# KCONFIG CHECK
+#
+# Implemented value types:
+# - boolean (e.g. '"ANDROID_PARANOID_NETWORK": False'):
+#   - False: disabled
+#   - True: enabled, either as module or built-in
+# - array (e.g. '"ANDROID_BINDER_DEVICES": ["binder", "hwbinder"]'):
+#   - each element of the array must be contained in the kernel config string,
+#     in any order. The example above would accept the following in the config:
+#       CONFIG_ANDROID_BINDER_DEVICES="hwbinder,vndbinder,binder"
+# - string (e.g. '"LSM": "lockdown,yama,loadpin,safesetid,integrity"'):
+#   - the value in the kernel config must be the same as the given string. Use
+#     this e.g. if the order of the elements is important.
+
 # Necessary kernel config options
 necessary_kconfig_options = {
     ">=0.0.0": {  # all versions
@@ -262,9 +280,11 @@ necessary_kconfig_options = {
             "ANDROID_PARANOID_NETWORK": False,
             "BLK_DEV_INITRD": True,
             "CGROUPS": True,
+            "CRYPTO_AES": True,
             "CRYPTO_XTS": True,
             "DEVTMPFS": True,
             "DM_CRYPT": True,
+            "INPUT_EVDEV": True,
             "EXT4_FS": True,
             "KINETO_GAN": False,
             "PFT": False,
@@ -295,7 +315,7 @@ necessary_kconfig_options = {
     }
 }
 
-# Necessary anbox kernel config options
+# Necessary anbox/waydroid kernel config options (android app support)
 necessary_kconfig_options_anbox = {
     ">=0.0.0": {  # all versions
         "all": {  # all arches
@@ -327,7 +347,55 @@ necessary_kconfig_options_anbox = {
     }
 }
 
-# Necessary nftables kernel config options
+# Necessary apparmor kernel config options (mandatory access control)
+# LSM: the value that "config LSM" sets in security/Kconfig, if
+# DEFAULT_SECURITY_APPARMOR is set (and other DEFAULT_SECURITY_* are unset).
+necessary_kconfig_options_apparmor = {
+    ">=0.0.0": {  # all versions
+        "all": {  # all arches
+            "AUDIT": True,
+            "DEFAULT_SECURITY_APPARMOR": True,
+            "LSM": "landlock,lockdown,yama,loadpin,safesetid,integrity,"
+                   "apparmor,selinux,smack,tomoyo,bpf",
+            "SECURITY_APPARMOR": True,
+        },
+    },
+    "<5.1": {
+        "all": {
+            "SECURITY_APPARMOR_BOOTPARAM_VALUE": True,
+        },
+    },
+}
+
+# Necessary iwd kernel config options (inet wireless daemon)
+# Obtained from 'grep ADD_MISSING src/main.c' in iwd.git
+necessary_kconfig_options_iwd = {
+    ">=0.0.0": {  # all versions
+        "all": {  # all arches
+            "ASYMMETRIC_KEY_TYPE": True,
+            "ASYMMETRIC_PUBLIC_KEY_SUBTYPE": True,
+            "CRYPTO_AES": True,
+            "CRYPTO_CBC": True,
+            "CRYPTO_CMAC": True,
+            "CRYPTO_DES": True,
+            "CRYPTO_ECB": True,
+            "CRYPTO_HMAC": True,
+            "CRYPTO_MD5": True,
+            "CRYPTO_SHA1": True,
+            "CRYPTO_SHA256": True,
+            "CRYPTO_SHA512": True,
+            "CRYPTO_USER_API_HASH": True,
+            "CRYPTO_USER_API_SKCIPHER": True,
+            "KEYS": True,
+            "KEY_DH_OPERATIONS": True,
+            "PKCS7_MESSAGE_PARSER": True,
+            "PKCS8_PRIVATE_KEY_PARSER": True,
+            "X509_CERTIFICATE_PARSER": True,
+        },
+    },
+}
+
+# Necessary nftables kernel config options (firewall)
 necessary_kconfig_options_nftables = {
     ">=3.13.0": {  # nftables support introduced here
         "all": {  # all arches
@@ -469,11 +537,12 @@ necessary_kconfig_options_containers = {
     },
 }
 
+# Necessary zram kernel config options (RAM disk with on-the-fly compression)
 necessary_kconfig_options_zram = {
     ">=3.14.0": {  # zram support introduced here
         "all": {  # all arches
-            "ZSMALLOC_STAT": True,
-            "ZRAM_MEMORY_TRACKING": True,
+            "ZRAM": True,
+            "ZSMALLOC": True,
             "CRYPTO_LZ4": True,
             "LZ4_COMPRESS": True,
             "SWAP": True,
@@ -490,6 +559,7 @@ apkbuild_package_attributes = {
     "pkgdesc": {},
     "depends": {"array": True},
     "provides": {"array": True},
+    "provider_priority": {"int": True},
     "install": {"array": True},
 
     # UI meta-packages can specify apps in "_pmb_recommends" to be explicitly
@@ -502,6 +572,11 @@ apkbuild_package_attributes = {
     # UI meta-packages can specify groups to which the user must be added
     # to access specific hardware such as LED indicators.
     "_pmb_groups": {"array": True},
+
+    # postmarketos-base, UI and device packages can use _pmb_select to provide
+    # additional configuration options in "pmbootstrap init" that allow
+    # selecting alternative providers for a virtual APK package.
+    "_pmb_select": {"array": True},
 }
 
 # Variables in APKBUILD files that get parsed
@@ -658,7 +733,14 @@ install_user_groups = ["wheel", "video", "audio", "input", "plugdev", "netdev"]
 # FLASH
 #
 
-flash_methods = ["fastboot", "heimdall", "0xffff", "uuu", "none"]
+flash_methods = [
+    "0xffff",
+    "fastboot",
+    "heimdall",
+    "none"
+    "rkdeveloptool",
+    "uuu",
+]
 
 # These folders will be mounted at the same location into the native
 # chroot, before the flash programs get started.
@@ -706,6 +788,8 @@ flashers = {
                             "$BOOT/dtbo.img"]],
             "boot": [["fastboot", "--cmdline", "$KERNEL_CMDLINE",
                       "boot", "$BOOT/boot.img$FLAVOR"]],
+            "flash_lk2nd": [["fastboot", "flash", "$PARTITION_KERNEL",
+                             "$BOOT/lk2nd.img"]]
         },
     },
     # Some devices provide Fastboot but using Android boot images is not
@@ -785,6 +869,15 @@ flashers = {
                 ["uuu", "flash_script.lst"],
             ],
         },
+    },
+    "rkdeveloptool": {
+        "depends": ["rkdeveloptool"],
+        "actions": {
+            "list_devices": [["rkdeveloptool", "ld"]],
+            "flash_rootfs": [
+                ["rkdeveloptool", "wl", "0", "$IMAGE"]
+            ],
+        },
     }
 }
 
