@@ -14,6 +14,7 @@ import pmb.helpers.devices
 import pmb.helpers.http
 import pmb.helpers.logging
 import pmb.helpers.other
+import pmb.helpers.pmaports
 import pmb.helpers.run
 import pmb.helpers.ui
 import pmb.chroot.zap
@@ -47,7 +48,7 @@ def ask_for_work_path(args):
     while True:
         try:
             work = os.path.expanduser(pmb.helpers.cli.ask(
-                args, "Work path", None, args.work, False))
+                "Work path", None, args.work, False))
             work = os.path.realpath(work)
             exists = os.path.exists(work)
 
@@ -103,7 +104,7 @@ def ask_for_channel(args):
 
     # Ask until user gives valid channel
     while True:
-        ret = pmb.helpers.cli.ask(args, "Channel", None, default,
+        ret = pmb.helpers.cli.ask("Channel", None, default,
                                   complete=choices)
         if ret in choices:
             return ret
@@ -111,8 +112,7 @@ def ask_for_channel(args):
                       " from the list above.")
 
 
-def ask_for_ui(args, device):
-    info = pmb.parse.deviceinfo(args, device)
+def ask_for_ui(args, info):
     ui_list = pmb.helpers.ui.list(args, info["arch"])
     hidden_ui_count = 0
     device_is_accelerated = info.get("gpu_accelerated") == "true"
@@ -138,7 +138,7 @@ def ask_for_ui(args, device):
                      " available. See: <https://wiki.postmarketos.org/wiki/"
                      "Deviceinfo_reference")
     while True:
-        ret = pmb.helpers.cli.ask(args, "User interface", None, args.ui, True,
+        ret = pmb.helpers.cli.ask("User interface", None, args.ui, True,
                                   complete=ui_completion_list)
         if ret in dict(ui_list).keys():
             return ret
@@ -163,8 +163,7 @@ def ask_for_ui_extras(args, ui):
                                    default=args.ui_extras)
 
 
-def ask_for_keymaps(args, device):
-    info = pmb.parse.deviceinfo(args, device)
+def ask_for_keymaps(args, info):
     if "keymaps" not in info or info["keymaps"].strip() == "":
         return ""
     options = info["keymaps"].split(' ')
@@ -174,7 +173,7 @@ def ask_for_keymaps(args, device):
         args.keymap = options[0]
 
     while True:
-        ret = pmb.helpers.cli.ask(args, "Keymap", None, args.keymap,
+        ret = pmb.helpers.cli.ask("Keymap", None, args.keymap,
                                   True, complete=options)
         if ret in options:
             return ret
@@ -208,6 +207,80 @@ def ask_for_timezone(args):
     return "GMT"
 
 
+def ask_for_provider_select(args, apkbuild, providers_cfg):
+    """
+    Ask for selectable providers that are specified using "_pmb_select"
+    in a APKBUILD.
+
+    :param apkbuild: the APKBUILD with the _pmb_select
+    :param providers_cfg: the configuration section with previously selected
+                          providers. Updated with new providers after selection
+    """
+    for select in apkbuild["_pmb_select"]:
+        providers = pmb.helpers.pmaports.find_providers(args, select)
+        logging.info(f"Available providers for {select} ({len(providers)}):")
+
+        has_default = False
+        providers_short = {}
+        last_selected = providers_cfg.get(select, 'default')
+
+        for pkgname, pkg in providers:
+            # Strip provider prefix if possible
+            short = pkgname
+            if short.startswith(f'{select}-'):
+                short = short[len(f"{select}-"):]
+
+            # Allow selecting the package using both short and long name
+            providers_short[pkgname] = pkgname
+            providers_short[short] = pkgname
+
+            if pkgname == last_selected:
+                last_selected = short
+
+            if not has_default and pkg.get('provider_priority', 0) != 0:
+                # Display as default provider
+                styles = pmb.config.styles
+                logging.info(f"* {short}: {pkg['pkgdesc']} "
+                             f"{styles['BOLD']}(default){styles['END']}")
+                has_default = True
+            else:
+                logging.info(f"* {short}: {pkg['pkgdesc']}")
+
+        while True:
+            ret = pmb.helpers.cli.ask("Provider", None, last_selected, True,
+                                      complete=providers_short.keys())
+
+            if has_default and ret == 'default':
+                # Selecting default means to not select any provider explicitly
+                # In other words, apk chooses it automatically based on
+                # "provider_priority"
+                if select in providers_cfg:
+                    del providers_cfg[select]
+                break
+            if ret in providers_short:
+                providers_cfg[select] = providers_short[ret]
+                break
+            logging.fatal("ERROR: Invalid provider specified, please type in"
+                          " one from the list above.")
+
+
+def ask_for_provider_select_pkg(args, pkgname, providers_cfg):
+    """
+    Look up the APKBUILD for the specified pkgname and ask for selectable
+    providers that are specified using "_pmb_select".
+
+    :param pkgname: name of the package to search APKBUILD for
+    :param providers_cfg: the configuration section with previously selected
+                          providers. Updated with new providers after selection
+    """
+    apkbuild = pmb.helpers.pmaports.get(args, pkgname,
+                                        subpackages=False, must_exist=False)
+    if not apkbuild:
+        return
+
+    ask_for_provider_select(args, apkbuild, providers_cfg)
+
+
 def ask_for_device_kernel(args, device):
     """
     Ask for the kernel that should be used with the device.
@@ -241,7 +314,7 @@ def ask_for_device_kernel(args, device):
     for type in sorted(kernels.keys()):
         logging.info(f"* {type}: {kernels[type]}")
     while True:
-        ret = pmb.helpers.cli.ask(args, "Kernel", None, default, True,
+        ret = pmb.helpers.cli.ask("Kernel", None, default, True,
                                   complete=kernels)
         if ret in kernels.keys():
             return ret
@@ -310,7 +383,7 @@ def ask_for_device(args):
         current_codename = args.device.split("-", 1)[1]
 
     while True:
-        vendor = pmb.helpers.cli.ask(args, "Vendor", None, current_vendor,
+        vendor = pmb.helpers.cli.ask("Vendor", None, current_vendor,
                                      False, r"[a-z0-9]+", vendors)
 
         new_vendor = vendor not in vendors
@@ -332,7 +405,7 @@ def ask_for_device(args):
 
         if current_vendor != vendor:
             current_codename = ''
-        codename = pmb.helpers.cli.ask(args, "Device codename", None,
+        codename = pmb.helpers.cli.ask("Device codename", None,
                                        current_codename, False, r"[a-z0-9]+",
                                        codenames)
 
@@ -390,20 +463,20 @@ def ask_for_additional_options(args, cfg):
                  " enough to fit the rootfs (pmbootstrap#1904)."
                  " How much extra free space do you want to add to the image"
                  " (in MB)?")
-    answer = pmb.helpers.cli.ask(args, "Extra space size", None,
+    answer = pmb.helpers.cli.ask("Extra space size", None,
                                  args.extra_space, validation_regex="^[0-9]+$")
     cfg["pmbootstrap"]["extra_space"] = answer
 
     # Boot size
     logging.info("What should be the boot partition size (in MB)?")
-    answer = pmb.helpers.cli.ask(args, "Boot size", None, args.boot_size,
+    answer = pmb.helpers.cli.ask("Boot size", None, args.boot_size,
                                  validation_regex="^[1-9][0-9]*$")
     cfg["pmbootstrap"]["boot_size"] = answer
 
     # Parallel job count
     logging.info("How many jobs should run parallel on this machine, when"
                  " compiling?")
-    answer = pmb.helpers.cli.ask(args, "Jobs", None, args.jobs,
+    answer = pmb.helpers.cli.ask("Jobs", None, args.jobs,
                                  validation_regex="^[1-9][0-9]*$")
     cfg["pmbootstrap"]["jobs"] = answer
 
@@ -414,7 +487,7 @@ def ask_for_additional_options(args, cfg):
                  " current usage with 'pmbootstrap stats'. Answer with 0 for"
                  " infinite.")
     regex = "0|[0-9]+(k|M|G|T|Ki|Mi|Gi|Ti)"
-    answer = pmb.helpers.cli.ask(args, "Ccache size", None, args.ccache_size,
+    answer = pmb.helpers.cli.ask("Ccache size", None, args.ccache_size,
                                  lowercase_answer=False,
                                  validation_regex=regex)
     cfg["pmbootstrap"]["ccache_size"] = answer
@@ -483,7 +556,7 @@ def ask_for_mirror(args):
     mirrors_list = []
     # require one valid mirror index selected by user
     while len(mirrors_list) != 1:
-        answer = pmb.helpers.cli.ask(args, "Select a mirror", None,
+        answer = pmb.helpers.cli.ask("Select a mirror", None,
                                      ",".join(mirror_indexes),
                                      validation_regex=regex)
         mirrors_list = []
@@ -499,8 +572,7 @@ def ask_for_mirror(args):
 
 def ask_for_hostname(args, device):
     while True:
-        ret = pmb.helpers.cli.ask(args,
-                                  "Device hostname (short form, e.g. 'foo')",
+        ret = pmb.helpers.cli.ask("Device hostname (short form, e.g. 'foo')",
                                   None, (args.hostname or device), True)
         if not pmb.helpers.other.validate_hostname(ret):
             continue
@@ -531,7 +603,7 @@ def ask_build_pkgs_on_install(args):
 def ask_for_locale(args):
     locales = pmb.config.locales
     logging.info(f"Available locales ({len(locales)}): {', '.join(locales)}")
-    return pmb.helpers.cli.ask(args, "Choose default locale for installation",
+    return pmb.helpers.cli.ask("Choose default locale for installation",
                                choices=None,
                                default=args.locale,
                                lowercase_answer=False,
@@ -569,25 +641,36 @@ def frontend(args):
     cfg["pmbootstrap"]["nonfree_firmware"] = str(nonfree["firmware"])
     cfg["pmbootstrap"]["nonfree_userland"] = str(nonfree["userland"])
 
+    info = pmb.parse.deviceinfo(args, device)
+    apkbuild_path = pmb.helpers.devices.find_path(args, device, 'APKBUILD')
+    if apkbuild_path:
+        apkbuild = pmb.parse.apkbuild(args, apkbuild_path)
+        ask_for_provider_select(args, apkbuild, cfg["providers"])
+
     # Device keymap
     if device_exists:
-        cfg["pmbootstrap"]["keymap"] = ask_for_keymaps(args, device)
+        cfg["pmbootstrap"]["keymap"] = ask_for_keymaps(args, info)
 
     # Username
-    cfg["pmbootstrap"]["user"] = pmb.helpers.cli.ask(args, "Username", None,
+    cfg["pmbootstrap"]["user"] = pmb.helpers.cli.ask("Username", None,
                                                      args.user, False,
                                                      "[a-z_][a-z0-9_-]*")
+
+    ask_for_provider_select_pkg(args, "postmarketos-base", cfg["providers"])
+
     # UI and various build options
-    ui = ask_for_ui(args, device)
+    ui = ask_for_ui(args, info)
     cfg["pmbootstrap"]["ui"] = ui
     cfg["pmbootstrap"]["ui_extras"] = str(ask_for_ui_extras(args, ui))
+    ask_for_provider_select_pkg(args, f"postmarketos-ui-{ui}",
+                                cfg["providers"])
     ask_for_additional_options(args, cfg)
 
     # Extra packages to be installed to rootfs
     logging.info("Additional packages that will be installed to rootfs."
                  " Specify them in a comma separated list (e.g.: vim,file)"
                  " or \"none\"")
-    extra = pmb.helpers.cli.ask(args, "Extra packages", None,
+    extra = pmb.helpers.cli.ask("Extra packages", None,
                                 args.extra_packages,
                                 validation_regex=r"^([-.+\w]+)(,[-.+\w]+)*$")
     cfg["pmbootstrap"]["extra_packages"] = extra
@@ -620,7 +703,7 @@ def frontend(args):
             pmb.helpers.cli.confirm(
                 args, "Zap existing chroots to apply configuration?",
                 default=True)):
-        setattr(args, "deviceinfo", pmb.parse.deviceinfo(args, device=device))
+        setattr(args, "deviceinfo", info)
 
         # Do not zap any existing packages or cache_http directories
         pmb.chroot.zap(args, confirm=False)
