@@ -368,7 +368,7 @@ def kconfig(args):
     if args.action_kconfig == "check":
         # Handle passing a file directly
         if args.file:
-            if pmb.parse.kconfig.check_file(args, args.package,
+            if pmb.parse.kconfig.check_file(args.package,
                                             anbox=args.anbox,
                                             nftables=args.nftables,
                                             containers=args.containers,
@@ -403,6 +403,8 @@ def kconfig(args):
             if not pmb.parse.kconfig.check(
                     args, package,
                     force_anbox_check=args.anbox,
+                    force_apparmor_check=args.apparmor,
+                    force_iwd_check=args.iwd,
                     force_nftables_check=args.nftables,
                     force_containers_check=args.containers,
                     force_zram_check=args.zram,
@@ -507,7 +509,7 @@ def shutdown(args):
 def stats(args):
     # Chroot suffix
     suffix = "native"
-    if args.arch != args.arch_native:
+    if args.arch != pmb.config.arch_native:
         suffix = "buildroot_" + args.arch
 
     # Install ccache and display stats
@@ -551,7 +553,7 @@ def bootimg_analyze(args):
     bootimg = pmb.parse.bootimg(args, args.path)
     tmp_output = "Put these variables in the deviceinfo file of your device:\n"
     for line in pmb.aportgen.device.\
-            generate_deviceinfo_fastboot_content(args, bootimg).split("\n"):
+            generate_deviceinfo_fastboot_content(bootimg).split("\n"):
         tmp_output += "\n" + line.lstrip()
     logging.info(tmp_output)
 
