@@ -92,7 +92,7 @@ def print_checks_git_repo(args, repo, details=True):
     log_ok("up to date with remote branch")
 
     # Outdated remote information
-    if pmb.helpers.git.is_outdated(args, path):
+    if pmb.helpers.git.is_outdated(path):
         return log_nok_ret(-5, "outdated remote information",
                            "update with 'pmbootstrap pull'")
     log_ok("remote information updated recently (via git fetch/pull)")
