@@ -698,6 +698,14 @@ def print_flash_info(args):
                      " the kernel/initramfs directly without flashing."
                      " Use 'pmbootstrap flasher boot' to do that.)")
 
+    if "flash_lk2nd" in flasher_actions and \
+            os.path.exists(args.work + "/chroot_rootfs_" + args.device +
+                           "/boot/lk2nd.img"):
+        logging.info(" * Your device supports and may even require"
+                     " flashing lk2nd. You should flash it before"
+                     " flashing anything else. Use 'pmbootstrap flasher"
+                     " flash_lk2nd' to do that.")
+
     # Export information
     logging.info("* If the above steps do not work, you can also create"
                  " symlinks to the generated files with 'pmbootstrap export'"
@@ -789,6 +797,24 @@ def install_on_device_installer(args, step, steps):
                          boot_label, "pmOS_install", args.split, args.sdcard)
 
 
+def get_selected_providers(args, packages):
+    """
+    Look through the specified packages and see which providers were selected
+    in "pmbootstrap init". Install those as extra packages to select them
+    instead of the default provider.
+
+    :param packages: the packages that have selectable providers (_pmb_select)
+    :return: additional provider packages to install
+    """
+    providers = []
+    for p in packages:
+        apkbuild = pmb.helpers.pmaports.get(args, p, subpackages=False)
+        for select in apkbuild['_pmb_select']:
+            if select in args.selected_providers:
+                providers.append(args.selected_providers[select])
+    return providers
+
+
 def create_device_rootfs(args, step, steps):
     # List all packages to be installed (including the ones specified by --add)
     # and upgrade the installed packages/apkindexes
@@ -802,17 +828,23 @@ def create_device_rootfs(args, step, steps):
 
     # Fill install_packages
     install_packages = (pmb.config.install_device_packages +
-                        ["device-" + args.device] +
-                        get_kernel_package(args, args.device) +
-                        get_nonfree_packages(args, args.device) +
-                        pmb.install.ui.get_recommends(args))
+                        ["device-" + args.device])
     if not args.install_base:
         install_packages = [p for p in install_packages
                             if p != "postmarketos-base"]
     if args.ui.lower() != "none":
         install_packages += ["postmarketos-ui-" + args.ui]
+
+    # Add additional providers of base/device/UI package
+    install_packages += get_selected_providers(args, install_packages)
+
+    install_packages += get_kernel_package(args, args.device)
+    install_packages += get_nonfree_packages(args, args.device)
+    if args.ui.lower() != "none":
         if args.ui_extras:
             install_packages += ["postmarketos-ui-" + args.ui + "-extras"]
+        if args.install_recommends:
+            install_packages += pmb.install.ui.get_recommends(args)
     if args.extra_packages.lower() != "none":
         install_packages += args.extra_packages.split(",")
     if args.add:
