@@ -217,6 +217,14 @@ def arguments_flasher(subparser):
                               help="partition to flash the kernel to (defaults"
                                    " to deviceinfo_flash_*_partition_kernel)")
 
+    # Flash lk2nd
+    flash_lk2nd = sub.add_parser("flash_lk2nd",
+                                 help="flash lk2nd, a secondary bootloader"
+                                 " needed for various Android devices")
+    flash_lk2nd.add_argument("--partition", default=None,
+                             help="partition to flash lk2nd to (defaults to"
+                             " default boot image partition ")
+
     # Flash rootfs
     flash_rootfs = sub.add_parser("flash_rootfs", aliases=["flash_system"],
                                   help="flash the rootfs to a partition on the"
@@ -416,7 +424,7 @@ def arguments_newapkbuild(subparser):
 
 def arguments_kconfig(subparser):
     # Allowed architectures
-    arch_native = pmb.parse.arch.alpine_native()
+    arch_native = pmb.config.arch_native
     arch_choices = set(pmb.config.build_device_architectures + [arch_native])
 
     # Kconfig subparser
@@ -434,15 +442,17 @@ def arguments_kconfig(subparser):
                        " directly instead of a config in a package")
     check.add_argument("--anbox", action="store_true", help="check"
                        " options needed for anbox too")
+    check.add_argument("--apparmor", action="store_true", help="check"
+                       " options needed for apparmor too")
+    check.add_argument("--iwd", action="store_true", help="check"
+                       " options needed for iwd too")
     check.add_argument("--nftables", action="store_true", help="check"
                        " options needed for nftables too")
     check.add_argument("--containers", action="store_true",
                        help="check options needed for containers too")
     check.add_argument("--zram", action="store_true", help="check"
                        " options needed for zram support too")
-    check_package = check.add_argument("package", default="", nargs='?')
-    if argcomplete:
-        check_package.completer = kernel_completer
+    add_kernel_arg(check)
 
     # "pmbootstrap kconfig edit"
     edit = sub.add_parser("edit", help="edit kernel aport config")
@@ -453,9 +463,7 @@ def arguments_kconfig(subparser):
     edit.add_argument("-n", dest="nconfig", action="store_true",
                       help="use nconfig rather than menuconfig for kernel"
                            " configuration")
-    edit_package = edit.add_argument("package", nargs='?')
-    if argcomplete:
-        edit_package.completer = kernel_completer
+    add_kernel_arg(edit)
 
     # "pmbootstrap kconfig migrate"
     migrate = sub.add_parser("migrate",
@@ -464,9 +472,7 @@ def arguments_kconfig(subparser):
                                   "which asks question for every new kernel "
                                   "config option.")
     migrate.add_argument("--arch", choices=arch_choices, dest="arch")
-    migrate_package = migrate.add_argument("package", nargs='?')
-    if argcomplete:
-        migrate_package.completer = kernel_completer
+    add_kernel_arg(migrate)
 
 
 def arguments_repo_missing(subparser):
@@ -476,7 +482,7 @@ def arguments_repo_missing(subparser):
     if argcomplete:
         package.completer = package_completer
     ret.add_argument("--arch", choices=pmb.config.build_device_architectures,
-                     default=pmb.parse.arch.alpine_native())
+                     default=pmb.config.arch_native)
     ret.add_argument("--built", action="store_true",
                      help="include packages which exist in the binary repos")
     ret.add_argument("--overview", action="store_true",
@@ -498,7 +504,7 @@ def arguments_status(subparser):
     return ret
 
 
-def package_completer(prefix, action, parser, parsed_args):
+def package_completer(prefix, action, parser=None, parsed_args=None):
     args = parsed_args
     pmb.config.merge_with_args(args)
     pmb.helpers.args.replace_placeholders(args)
@@ -509,10 +515,21 @@ def package_completer(prefix, action, parser, parsed_args):
     return packages
 
 
-def kernel_completer(prefix, action, parser, parsed_args):
-    packages = package_completer("linux-" + prefix, action, parser,
+def kernel_completer(prefix, action, parser=None, parsed_args=None):
+    """ :returns: matched linux-* packages, with linux-* prefix and without """
+    ret = []
+
+    # Full package name, starting with "linux-"
+    if (len("linux-") < len(prefix) and prefix.startswith("linux-") or
+            "linux-".startswith(prefix)):
+        ret += package_completer(prefix, action, parser, parsed_args)
+
+    # Kernel name without "linux-"
+    packages = package_completer(f"linux-{prefix}", action, parser,
                                  parsed_args)
-    return [package.replace("linux-", "", 1) for package in packages]
+    ret += [package.replace("linux-", "", 1) for package in packages]
+
+    return ret
 
 
 def add_packages_arg(subparser, name="packages", *args, **kwargs):
@@ -521,9 +538,16 @@ def add_packages_arg(subparser, name="packages", *args, **kwargs):
         arg.completer = package_completer
 
 
+def add_kernel_arg(subparser, name="package", *args, **kwargs):
+    arg = subparser.add_argument("package", nargs='?', help="kernel package"
+                                 " (e.g. linux-postmarketos-allwinner)")
+    if argcomplete:
+        arg.completer = kernel_completer
+
+
 def arguments():
     parser = argparse.ArgumentParser(prog="pmbootstrap")
-    arch_native = pmb.parse.arch.alpine_native()
+    arch_native = pmb.config.arch_native
     arch_choices = set(pmb.config.build_device_architectures + [arch_native])
     mirrors_pmos_default = pmb.config.defaults["mirrors_postmarketos"]
 
