@@ -44,7 +44,7 @@ def create_second_storage(args):
     return path
 
 
-def which_qemu(args, arch):
+def which_qemu(arch):
     """
     Finds the qemu executable or raises an exception otherwise
     """
@@ -104,15 +104,22 @@ def command_qemu(args, arch, img_path, img_path_2nd=None):
     if pmaports_cfg.get("supported_mkinitfs_without_flavors", False):
         flavor_suffix = ""
 
+    # Alpine kernels always have the flavor appended to /boot/vmlinuz
+    kernel = f"{rootfs}/boot/vmlinuz{flavor_suffix}"
+    if not os.path.exists(kernel):
+        kernel = f"{kernel}-{flavor}"
+        if not os.path.exists(kernel):
+            raise RuntimeError("failed to find the proper vmlinuz path")
+
     ncpus = os.cpu_count()
 
     # QEMU mach-virt's max CPU count is 8, limit it so it will work correctly
     # on systems with more than 8 CPUs
-    if arch != args.arch_native and ncpus > 8:
+    if arch != pmb.config.arch_native and ncpus > 8:
         ncpus = 8
 
     if args.host_qemu:
-        qemu_bin = which_qemu(args, arch)
+        qemu_bin = which_qemu(arch)
         env = {}
         command = [qemu_bin]
     else:
@@ -130,7 +137,7 @@ def command_qemu(args, arch, img_path, img_path_2nd=None):
                         rootfs_native + "/usr/share"})
 
         command = []
-        if args.arch_native in ["aarch64", "armv7"]:
+        if pmb.config.arch_native in ["aarch64", "armv7"]:
             # Workaround for QEMU failing on aarch64 asymetric multiprocessor
             # arch (big/little architecture
             # https://en.wikipedia.org/wiki/ARM_big.LITTLE) see
@@ -141,12 +148,12 @@ def command_qemu(args, arch, img_path, img_path_2nd=None):
                 logging.info("QEMU will run on big/little architecture on the"
                              f" first {ncpus} cores (from /proc/cpuinfo)")
                 command += [rootfs_native + "/lib/ld-musl-" +
-                            args.arch_native + ".so.1"]
+                            pmb.config.arch_native + ".so.1"]
                 command += [rootfs_native + "/usr/bin/taskset"]
                 command += ["-c", "0-" + str(ncpus - 1)]
 
         command += [rootfs_native + "/lib/ld-musl-" +
-                    args.arch_native + ".so.1"]
+                    pmb.config.arch_native + ".so.1"]
         command += ["--library-path=" + rootfs_native + "/lib:" +
                     rootfs_native + "/usr/lib:" +
                     rootfs_native + "/usr/lib/pulseaudio"]
@@ -154,7 +161,7 @@ def command_qemu(args, arch, img_path, img_path_2nd=None):
         command += ["-L", rootfs_native + "/usr/share/qemu/"]
 
     command += ["-nodefaults"]
-    command += ["-kernel", rootfs + "/boot/vmlinuz" + flavor_suffix]
+    command += ["-kernel", kernel]
     command += ["-initrd", rootfs + "/boot/initramfs" + flavor_suffix]
     command += ["-append", shlex.quote(cmdline)]
 
@@ -189,7 +196,7 @@ def command_qemu(args, arch, img_path, img_path_2nd=None):
                            " yet.")
 
     # Kernel Virtual Machine (KVM) support
-    native = args.arch_native == args.deviceinfo["arch"]
+    native = pmb.config.arch_native == args.deviceinfo["arch"]
     if args.qemu_kvm and native and os.path.exists("/dev/kvm"):
         command += ["-enable-kvm"]
         command += ["-cpu", "host"]
